@@ -1,5 +1,5 @@
 /*******************************************************************************
-    Copyright (c) 2015 NVidia Corporation
+    Copyright (c) 2015-2019 NVidia Corporation
 
     Permission is hereby granted, free of charge, to any person obtaining a copy
     of this software and associated documentation files (the "Software"), to
@@ -1137,6 +1137,22 @@ typedef struct
     NV_STATUS                       rmStatus;                                           // Out
 } UVM_TEST_PMM_RELEASE_FREE_ROOT_CHUNKS_PARAMS;
 
+// Wait until all pending replayable faults have been processed. If there are
+// still pending packets when timeout_ns is reached, the ioctl returns
+// NV_ERR_TIMEOUT.
+//
+// This function should be called after the kernel producing the faults has been
+// synchronized. This should ensure that PUT != GET and faults will not be
+// missed even if the driver has not started to process them, yet.
+#define UVM_TEST_DRAIN_REPLAYABLE_FAULTS                UVM8_TEST_IOCTL_BASE(74)
+typedef struct
+{
+    NvProcessorUuid                 gpu_uuid;                                           // In
+    NvU64                           timeout_ns;                                         // In
+
+    NV_STATUS                       rmStatus;                                           // Out
+} UVM_TEST_DRAIN_REPLAYABLE_FAULTS_PARAMS;
+
 #ifdef __cplusplus
 }
 #endif
